pub struct Modulo(pub Value);Expand description
An incomplete AST representation of a plural rule. Comprises a Value but is later expressed as % usize.
Examples
All AST nodes can be built explicitly, as seen in the example. However, due to its complexity, it is preferred to build the AST using the parse_plural_rule function.
"% 100"Will be used to represent the AST:
use cldr_pluralrules_parser::ast::*;
Modulo(Value(100));Tuple Fields
0: ValueTrait Implementations
impl StructuralPartialEq for Modulo